@@ -1,32 +1,32 @@
+use self::{
+    filter::{Filter, FilterCriterion},
+    sorter::{SortCriteria, SortOrder, Sorter},
+    state::AppState,
+};
+use crate::settings::Settings;
+use anyhow::{anyhow, bail, Context};
+use backend::{DataProvider, EntriesDTO, Entry, EntryDraft};
+use chrono::{DateTime, Utc};
+use rayon::prelude::*;
 use std::{
     collections::{BTreeSet, HashSet},
     fs::File,
     path::PathBuf,
 };
 
-use backend::{DataProvider, EntriesDTO, Entry, EntryDraft};
-
-use anyhow::{anyhow, bail, Context};
-use chrono::{DateTime, Utc};
-use rayon::prelude::*;
-
-pub use runner::run;
-pub use ui::UIComponents;
-
-#[cfg(test)]
-mod test;
-
 mod external_editor;
 mod filter;
 mod keymap;
 mod runner;
+mod sorter;
+mod state;
+#[cfg(test)]
+mod test;
 mod ui;
 
+pub use runner::run;
 pub use runner::HandleInputReturnType;
-
-use crate::settings::Settings;
-
-use self::filter::{Filter, FilterCritrion};
+pub use ui::UIComponents;
 
 pub struct App<D>
 where
@@ -42,6 +42,7 @@ where
     pub settings: Settings,
     pub redraw_after_restore: bool,
     pub filter: Option<Filter>,
+    state: AppState,
 }
 
 impl<D> App<D>
@@ -61,11 +62,12 @@ where
             settings,
             redraw_after_restore: false,
             filter: None,
+            state: Default::default(),
         }
     }
 
     /// Get entries that meet the filter criteria if any otherwise it returns all entries
-    pub fn get_active_entries(&self) -> impl Iterator<Item = &Entry> {
+    pub fn get_active_entries(&self) -> impl DoubleEndedIterator<Item = &Entry> {
         self.entries
             .iter()
             .filter(|entry| !self.filtered_out_entries.contains(&entry.id))
@@ -90,7 +92,7 @@ where
 
         self.entries = self.data_provide.load_all_entries().await?;
 
-        self.entries.sort_by(|a, b| b.date.cmp(&a.date));
+        self.sort_entries();
 
         self.update_filtered_out_entries();
 
@@ -102,12 +104,13 @@ where
         title: String,
         date: DateTime<Utc>,
         tags: Vec<String>,
+        priority: Option<u32>,
     ) -> anyhow::Result<u32> {
         log::trace!("Adding entry");
 
         let entry = self
             .data_provide
-            .add_entry(EntryDraft::new(date, title, tags))
+            .add_entry(EntryDraft::new(date, title, tags, priority))
             .await?;
         let entry_id = entry.id;
 
@@ -115,6 +118,7 @@ where
 
         self.entries.sort_by(|a, b| b.date.cmp(&a.date));
 
+        self.sort_entries();
         self.update_filtered_out_entries();
 
         Ok(entry_id)
@@ -125,6 +129,7 @@ where
         title: String,
         date: DateTime<Utc>,
         tags: Vec<String>,
+        priority: Option<u32>,
     ) -> anyhow::Result<()> {
         log::trace!("Updating entry");
 
@@ -137,6 +142,7 @@ where
         entry.title = title;
         entry.date = date;
         entry.tags = tags;
+        entry.priority = priority;
 
         let clone = entry.clone();
 
@@ -144,6 +150,8 @@ where
 
         self.entries.sort_by(|a, b| b.date.cmp(&a.date));
 
+        self.sort_entries();
+
         self.update_filter();
         self.update_filtered_out_entries();
 
@@ -253,13 +261,14 @@ where
             let all_tags = self.get_all_tags();
             let filter = self.filter.as_mut().unwrap();
 
-            filter.critria.retain(|cr| match cr {
-                FilterCritrion::Tag(tag) => all_tags.contains(tag),
-                FilterCritrion::Title(_) => true,
-                FilterCritrion::Content(_) => true,
+            filter.criteria.retain(|cr| match cr {
+                FilterCriterion::Tag(tag) => all_tags.contains(tag),
+                FilterCriterion::Title(_) => true,
+                FilterCriterion::Content(_) => true,
+                FilterCriterion::Priority(_) => true,
             });
 
-            if filter.critria.is_empty() {
+            if filter.criteria.is_empty() {
                 self.filter = None;
             }
         }
@@ -278,4 +287,45 @@ where
             self.filtered_out_entries.clear();
         }
     }
+
+    /// Assigns priority to all entries that don't have a priority assigned to
+    async fn assign_priority_to_entries(&self, priority: u32) -> anyhow::Result<()> {
+        self.data_provide
+            .assign_priority_to_entries(priority)
+            .await?;
+
+        Ok(())
+    }
+
+    pub fn apply_sort(&mut self, criteria: Vec<SortCriteria>, order: SortOrder) {
+        self.state.sorter.set_criteria(criteria);
+        self.state.sorter.order = order;
+
+        self.sort_entries();
+    }
+
+    fn sort_entries(&mut self) {
+        self.entries
+            .sort_by(|entry1, entry2| self.state.sorter.sort(entry1, entry2));
+    }
+
+    pub fn load_state(&mut self, ui_components: &mut UIComponents) {
+        let state = match AppState::load() {
+            Ok(state) => state,
+            Err(err) => {
+                ui_components.show_err_msg(format!(
+                    "Loading state failed. Falling back to default state\n\rError Info: {err}"
+                ));
+                AppState::default()
+            }
+        };
+
+        self.state = state;
+    }
+
+    pub fn persist_state(&self) -> anyhow::Result<()> {
+        self.state.save()?;
+
+        Ok(())
+    }
 }
