@@ -21,7 +21,7 @@ use crate::app::App;
 use super::INACTIVE_CONTROL_COLOR;
 use super::{UICommand, ACTIVE_CONTROL_COLOR};
 
-const LIST_INNER_MARGINE: usize = 5;
+const LIST_INNER_MARGIN: usize = 5;
 const SELECTED_FOREGROUND_COLOR: Color = Color::Yellow;
 
 #[derive(Debug)]
@@ -55,6 +55,7 @@ impl<'a> EntriesList {
                 let highlight_selected =
                     self.multi_select_mode && app.selected_entries.contains(&entry.id);
 
+                // *** Title ***
                 let mut title = entry.title.to_string();
 
                 if highlight_selected {
@@ -62,7 +63,7 @@ impl<'a> EntriesList {
                 }
 
                 // Text wrapping
-                let title_lines = textwrap::wrap(&title, area.width as usize - LIST_INNER_MARGINE);
+                let title_lines = textwrap::wrap(&title, area.width as usize - LIST_INNER_MARGIN);
 
                 // tilte lines
                 lines_count += title_lines.len();
@@ -83,28 +84,59 @@ impl<'a> EntriesList {
                     })
                     .collect();
 
-                spans.push(Line::from(Span::styled(
-                    format!(
+                // *** Date & Priority ***
+                let date_priority_lines = if let Some(prio) = entry.priority {
+                    let one_liner = format!(
+                        "{},{},{} | Priority: {}",
+                        entry.date.day(),
+                        entry.date.month(),
+                        entry.date.year(),
+                        prio
+                    );
+
+                    if one_liner.len() > area.width as usize - LIST_INNER_MARGIN {
+                        vec![
+                            format!(
+                                "{},{},{}",
+                                entry.date.day(),
+                                entry.date.month(),
+                                entry.date.year()
+                            ),
+                            format!("Priority: {prio}"),
+                        ]
+                    } else {
+                        vec![one_liner]
+                    }
+                } else {
+                    vec![format!(
                         "{},{},{}",
                         entry.date.day(),
                         entry.date.month(),
                         entry.date.year()
-                    ),
-                    Style::default()
-                        .fg(Color::LightBlue)
-                        .remove_modifier(Modifier::BOLD),
-                )));
+                    )]
+                };
 
-                // date line
-                lines_count += 1;
+                let date_lines = date_priority_lines.iter().map(|line| {
+                    Line::from(Span::styled(
+                        line.to_string(),
+                        Style::default()
+                            .fg(Color::LightBlue)
+                            .remove_modifier(Modifier::BOLD),
+                    ))
+                });
+                spans.extend(date_lines);
 
+                // date & priority lines
+                lines_count += date_priority_lines.len();
+
+                // *** Tags ***
                 if !entry.tags.is_empty() {
                     let tags: Vec<String> = entry.tags.iter().map(String::from).collect();
                     let tag_line = tags.join(" | ");
 
                     // Text wrapping
                     let tag_line =
-                        textwrap::wrap(&tag_line, area.width as usize - LIST_INNER_MARGINE);
+                        textwrap::wrap(&tag_line, area.width as usize - LIST_INNER_MARGIN);
 
                     lines_count += tag_line.len();
 
@@ -211,7 +243,6 @@ impl<'a> EntriesList {
         frame.render_widget(place_holder, area);
     }
 
-    #[inline]
     fn get_list_block(&self, has_filter: bool) -> Block<'a> {
         let title = match (self.multi_select_mode, has_filter) {
             (true, true) => "Journals - Multi-Select - Filtered",
